%define common_summary interact with virtualization capabilities
%define common_description Libvirt is a C toolkit to interact with the virtualization\
capabilities of recent versions of Linux.

%define lib_major 0

%define lib_name %mklibname virt %{lib_major}
%define develname %mklibname -d virt
%define staticdevelname %mklibname -d -s virt

# libxenstore is not versionned properly
%global __requires_exclude devel\\(libxenstore.*\\)

Name:       libvirt
Version:    1.2.9.3
%define subrel 3
Release:    %mkrel 1
Summary:    Toolkit to %{common_summary}
License:    LGPLv2+
Group:      System/Kernel and hardware
Url:        http://libvirt.org/
%if %(echo %{version} | grep -o \\. | wc -l) == 3
    %define mainturl stable_updates/
%endif
Source0:    http://libvirt.org/sources/%{?mainturl}%{name}-%{version}.tar.gz
Source1:    %{name}-tmpfiles.conf

Patch0:     libvirt-1.2.3-mga-no-daemonize.patch

# upstream patches
Patch56:    0056-conf-fix-issue-on-virCPUDefCopy.patch
Patch57:    0057-lxc-set-nosuid+nodev+noexec-flags-on-proc-sys-mount.patch
Patch58:    0058-Teach-virt-aa-helper-to-use-TEMPLATE-qemu-if-the-dom.patch
Patch59:    0059-Revert-LXC-show-used-memory-as-0-when-domain-is-not.patch
Patch60:    0060-remoteClientCloseFunc-Don-t-mangle-connection-object.patch
Patch61:    0061-CVE-2015-5313-storage-don-t-allow-slash-in-filesyste.patch

# reverted upstream commit after git bisect, hint from upstream as interim fix
# see https://bugzilla.redhat.com/show_bug.cgi?id=1308736#c5
# patch created via "git format-patch -1 a514d325d534f799d4e3af0163408fbb3e96d5bf" and then re-applying and reverting it
Patch62:    libvirt-1.2.9.3-mga-REVERT-Report-original-error-when-QMP-probing-fails-with-ne.patch

Requires:   cyrus-sasl
%ifarch %{ix86} x86_64
BuildRequires:  xen-devel >= 3.0.4
%endif
BuildRequires:  libxml2-devel
BuildRequires:  ncurses-devel
BuildRequires:  readline-devel
BuildRequires:  python
BuildRequires:  libgcrypt-devel
BuildRequires:  gnutls-devel
BuildRequires:  libsasl-devel
BuildRequires:  libpciaccess-devel
BuildRequires:  polkit-1-devel
BuildRequires:  parted-devel
BuildRequires:  libxml2-utils
BuildRequires:  nfs-utils 
BuildRequires:  libavahi-client-devel
BuildRequires:  xmlrpc-c-devel
BuildRequires:  numa-devel
BuildRequires:  qemu
BuildRequires:  gettext-devel
BuildRequires:  netcf-devel
BuildRequires:  libnl3-devel
BuildRequires:  libpcap-devel
BuildRequires:	curl-devel
BuildRequires:	libblkid-devel
BuildRequires:	libssh2-devel
BuildRequires:  systemtap
BuildRequires:  libyajl-devel
BuildRequires:  pkgconfig(systemd) >= 216
BuildRequires:  openssl-devel
# (tmb) build against kernel-devel-latest
%ifarch %{arm}
%define kflavour kirkwood
%else
%define kflavour desktop
%endif
BuildRequires:  kernel-%{kflavour}-devel-latest

# add userspace tools here because the full path to each tool is hard coded into the libvirt.so* library.
BuildRequires:  dmsetup 
BuildRequires:  dnsmasq-base 
BuildRequires:  ebtables 
BuildRequires:  iproute2 
BuildRequires:  iptables 
BuildRequires:  kmod 
BuildRequires:  lvm2 
BuildRequires:  numactl 
BuildRequires:  open-iscsi 
BuildRequires:  parted 
BuildRequires:  polkit 
BuildRequires:  radvd 
BuildRequires:  scrub 
BuildRequires:  systemd

%description
%{common_description}

Virtualization of the Linux Operating System means the
ability to run multiple instances of Operating Systems concurently on
a single hardware system where the basic resources are driven by a
Linux instance. The library aim at providing long term stable C API
initially for the Xen paravirtualization but should be able to
integrate other virtualization mechanisms if needed.

%package -n %{lib_name}
Summary:    A library to %{common_summary}
Group:      System/Libraries
# For LXC move (mga#14566)
Conflicts:  %{develname} <  %version-%release

%description -n %{lib_name}
%{common_description}

This package contains the library needed to run programs dynamically
linked with %{name}.

%package -n %{develname}
Summary:    Development tools for programs using %{name}
Group:      Development/C
Requires:   %{lib_name} = %{version}
%ifarch %{ix86} x86_64
Requires:   xen-devel
%endif
Provides:   %{name}-devel = %{version}-%{release}
Obsoletes:  %{lib_name}-devel
# For LXC move (mga#14566)
Conflicts:  %{lib_name} <  %version-%release

%description -n %{develname}
%{common_description}

This package contains the header files and libraries needed for
developing programs using the %{name} library.

%package -n %{staticdevelname}
Summary:    Development static libraries for programs using %{name}
Group:      Development/C
Provides:   %{name}-static-devel = %{version}-%{release}
Obsoletes:  %{lib_name}-static-devel

%description -n %{staticdevelname}
%{common_description}

This package contains the static libraries needed for developing
programs using the %{name} library.

%package -n %{name}-utils
Summary:    Tools to %{common_summary}
Group:      System/Kernel and hardware
Requires:   bridge-utils
Requires:   %{lib_name} = %{version}
Requires:   polkit
Requires:   ebtables
Requires:   netcf
# required by libvirt-guests.service
Requires:   gettext
Requires(post):  systemd >= %{systemd_required_version}
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1
# fix "Cannot check dnsmasq binary dnsmasq":
Recommends:   dnsmasq
Recommends:   netcat-openbsd
Conflicts:  libvirt0 < 0.7.1-2
Conflicts:  lib64virt0 < 0.7.1-2
Provides:   %{name}-client = %{version}-%{release}

%description -n %{name}-utils
%{common_description}

This package contains tools for the %{name} library.

%prep
%setup -q
%apply_patches

%build
autoreconf -fi
%configure2_5x --disable-static \
    --localstatedir=%{_var}  \
    --with-html-subdir=%{name} \
    --with-udev \
    --without-hal \
    --with-init_script=systemd \
    --with-openssl
%make

%install
%makeinstall_std SYSTEMD_UNIT_DIR=%{_unitdir}

rm -f %{buildroot}%{_initrddir}/libvirt-guests
find %{buildroot} -name '*.la' -delete

install -D -p -m 0644 %{SOURCE1} %{buildroot}%{_tmpfilesdir}/%{name}.conf
install -d -m 0755 %{buildroot}%{_var}/lib/%{name}
%find_lang %{name}

# fix documentation
#mv %{buildroot}%{_docdir}/%{name}-python-%{version} %{buildroot}%{_docdir}/python-%{name}
install -m 644 ChangeLog README TODO NEWS %{buildroot}%{_docdir}/%{name}

%check
# fhimpe: disabled for now because it fails on 100Hz kernels, such as used on bs
# http://www.mail-archive.com/libvir-list@redhat.com/msg13727.html
#make check

%post -n %{name}-utils
%_tmpfilescreate %{name}
%_post_service  libvirtd
%_post_service  libvirt-guests
%_post_service	virtlockd

%preun -n %{name}-utils
%_preun_service libvirt-guests
%_preun_service libvirtd
%_preun_service	virtlockd

%files -n %{lib_name}
%{_libdir}/%{name}.so.%{lib_major}*
%{_libdir}/%{name}-qemu.so.%{lib_major}*
%{_libdir}/%{name}-lxc.so.%{lib_major}*

%files -n %{develname}
%{_docdir}/%{name}
%exclude %{_docdir}/%{name}/ChangeLog
%exclude %{_docdir}/%{name}/README
%exclude %{_docdir}/%{name}/TODO
%exclude %{_docdir}/%{name}/NEWS
%doc %{_datadir}/gtk-doc/html/%{name}
%{_includedir}/%{name}
%{_libdir}/%{name}.so
%{_libdir}/%{name}-qemu.so
%{_libdir}/%{name}-lxc.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/pkgconfig/%{name}-lxc.pc
%{_libdir}/pkgconfig/%{name}-qemu.pc

%files -n %{name}-utils -f %{name}.lang
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/ChangeLog
%{_docdir}/%{name}/README
%{_docdir}/%{name}/TODO
%{_docdir}/%{name}/NEWS
%{_bindir}/*
%{_mandir}/man1/virsh.1*
%{_mandir}/man1/virt-xml-validate.1*
%{_mandir}/man1/virt-pki-validate.1*
%{_mandir}/man1/virt-host-validate.1*
%{_mandir}/man1/virt-login-shell.1*
%{_mandir}/man8/libvirtd.8.*
%{_mandir}/man8/virtlockd.8.*
%{_sbindir}/*
%{_unitdir}/libvirtd.service
%{_unitdir}/libvirtd.socket
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/qemu/
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/lxc/
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/uml/
%{_libexecdir}/libvirt_lxc
%{_libexecdir}/libvirt_leaseshelper
%{_libexecdir}/libvirt_parthelper
%{_libexecdir}/libvirt_iohelper
%{_libexecdir}/libvirt-guests.sh
%{_var}/lib/libvirt
%{_datadir}/polkit-1/actions/org.libvirt.unix.policy
%{_datadir}/polkit-1/actions/org.libvirt.api.policy
%{_datadir}/augeas/lenses/*.aug
%{_datadir}/augeas/lenses/tests/*.aug
%{_datadir}/systemtap/tapset/*.stp
%{_datadir}/%{name}
%config(noreplace) %{_sysconfdir}/libvirt
%config(noreplace) %{_sysconfdir}/sasl2/libvirt.conf
%config(noreplace) %{_sysconfdir}/sysconfig/libvirtd
%config(noreplace) %{_sysconfdir}/sysconfig/libvirt-guests
%config(noreplace) %{_sysconfdir}/sysconfig/virtlockd
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd*
%{_prefix}/lib/sysctl.d/libvirtd.conf
%{_unitdir}/libvirt-guests.service
%{_unitdir}/virtlockd.*
%{_tmpfilesdir}/%{name}.conf
%{_libdir}/libvirt/connection-driver
%dir %{_libdir}/libvirt/lock-driver
%{_libdir}/libvirt/lock-driver/*.so


%changelog
* Sat Mar 05 2016 doktor5000 <doktor5000> 1.2.9.3-1.3.mga5
+ Revision: 986071
- reverted upstream commit after git bisect and upstream report (mga#17417)
- added back dropped patch to reenable connections to libvirtd

  + luigiwalser <luigiwalser>
    - drop patch0 as it makes qemu connections fail completely (cjw)
    - 1.2.9.3
    - sync with upstream git including fix for CVE-2015-5313

* Sun May 10 2015 tv <tv> 1.2.9.2-2.mga5
+ Revision: 821611
- move LXC driver from devel to main package (mga#14566)

* Tue Mar 03 2015 luigiwalser <luigiwalser> 1.2.9.2-1.mga5
+ Revision: 817500
- 1.2.9.2
- remove upstreamed patches
- add latest upstream patches from 1.2.9 git branch as of 2015-02-26

* Tue Feb 03 2015 akien <akien> 1.2.9.1-5.mga5
+ Revision: 813311
- Rebuild for new xen

* Tue Jan 27 2015 luigiwalser <luigiwalser> 1.2.9.1-4.mga5
+ Revision: 812442
- sync upstream patches including fix for CVE-2015-0236

* Thu Dec 25 2014 luigiwalser <luigiwalser> 1.2.9.1-3.mga5
+ Revision: 805994
- sync upstream patches to fix CVE-2014-8135 and CVE-2014-8136

* Tue Dec 16 2014 luigiwalser <luigiwalser> 1.2.9.1-2.mga5
+ Revision: 803300
- sync upstream patches including fix for CVE-2014-8131

* Thu Dec 11 2014 luigiwalser <luigiwalser> 1.2.9.1-1.mga5
+ Revision: 802756
- 1.2.9.1

* Thu Nov 13 2014 luigiwalser <luigiwalser> 1.2.9-3.mga5
+ Revision: 796782
- sync patches from upstream 1.2.9 branch, including fix for CVE-2014-7823

* Wed Oct 15 2014 umeabot <umeabot> 1.2.9-2.mga5
+ Revision: 740377
- Second Mageia 5 Mass Rebuild

* Wed Oct 01 2014 luigiwalser <luigiwalser> 1.2.9-1.mga5
+ Revision: 733839
- 1.2.9 (fixes CVE-2014-3633 and CVE-2014-3657)

* Tue Sep 16 2014 umeabot <umeabot> 1.2.8-3.mga5
+ Revision: 681841
- Mageia 5 Mass Rebuild

  + tv <tv>
    - use %%global for req/prov exclude
    - autoconvert to new prov/req excludes
    - s/uggests:/Recommends:/

* Wed Sep 03 2014 joequant <joequant> 1.2.8-2.mga5
+ Revision: 671577
- bump version
- build with new systemd

* Wed Sep 03 2014 luigiwalser <luigiwalser> 1.2.8-1.mga5
+ Revision: 671143
- add libvirtd.socket to files list
- 1.2.8

  + alien <alien>
    - require gettext for libvirt-guests.service

* Tue Aug 05 2014 sander85 <sander85> 1.2.7-1.mga5
+ Revision: 659794
- New version: 1.2.7

* Sun Jul 27 2014 sander85 <sander85> 1.2.6-1.mga5
+ Revision: 657477
- New version: 1.2.6

* Wed Jun 04 2014 fwang <fwang> 1.2.5-1.mga5
+ Revision: 632734
- 1.2.5

* Sun May 18 2014 tmb <tmb> 1.2.4-2.mga5
+ Revision: 623566
- fix CVE-2014-0179

* Sun May 18 2014 tmb <tmb> 1.2.4-1.mga5
+ Revision: 623534
- update to 1.2.4

  + fwang <fwang>
    - 1.2.3

* Sun Mar 30 2014 tv <tv> 1.2.2-2.mga5
+ Revision: 610327
- rebuild for new xen

* Sat Mar 15 2014 joequant <joequant> 1.2.2-1.mga5
+ Revision: 603999
- upgrade to 1.2.2

* Fri Jan 24 2014 oden <oden> 1.2.1-1.mga4
+ Revision: 567696
- 1.2.1 (fixes CVE-2013-6436, CVE-2013-6457, CVE-2013-6458, CVE-2014-0028, CVE-2014-1447)

* Mon Nov 11 2013 luigiwalser <luigiwalser> 1.1.4-1.mga4
+ Revision: 550558
- 1.1.4 (fixes CVE-2013-4400 and CVE-2013-4401)

* Tue Oct 22 2013 umeabot <umeabot> 1.1.3-4.mga4
+ Revision: 545429
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 alien <alien> 1.1.3-3.mga4
+ Revision: 501003
- rebuild for XEN 4.3.0

* Thu Oct 10 2013 joequant <joequant> 1.1.3-2.mga4
+ Revision: 494792
- add netcf dependency

* Wed Oct 09 2013 luigiwalser <luigiwalser> 1.1.3-1.mga4
+ Revision: 494281
- 1.1.3
- remove upstream patches
- add 6 patches from fedora

  + oden <oden>
    - fix build deps

* Sun Sep 22 2013 colin <colin> 1.1.2-2.mga4
+ Revision: 483291
- Make polkit usage secure (mga#11260 CVE-2013-4311)

* Fri Sep 06 2013 fwang <fwang> 1.1.2-1.mga4
+ Revision: 475396
- new version 1.1.2 final

* Sat Aug 31 2013 joequant <joequant> 1.1.2-0.1.mga4
+ Revision: 473756
- upgrade to 1.1.2rc2

* Tue Aug 27 2013 luigiwalser <luigiwalser> 1.1.1-7.mga4
+ Revision: 472078
- rebuild for cyrus-sasl

* Mon Aug 26 2013 joequant <joequant> 1.1.1-6.mga4
+ Revision: 471876
- add buildrequires for dnsmasq to get location of libvirt

* Sun Aug 25 2013 joequant <joequant> 1.1.1-5.mga4
+ Revision: 471680
- put in nodaemonize patch

* Sat Aug 17 2013 joequant <joequant> 1.1.1-3.mga4
+ Revision: 467357
- add redhat patch to fix segfault.  This is needed for openstack nova

* Wed Jul 31 2013 fwang <fwang> 1.1.1-2.mga4
+ Revision: 461385
- add more br
- use autoreconf
- new version 1.1.1

* Mon Jul 29 2013 neoclust <neoclust> 1.1.0-1.mga4
+ Revision: 460623
- New version

* Tue Jun 04 2013 fwang <fwang> 1.0.6-1.mga4
+ Revision: 437152
- new version 1.0.6

* Wed May 29 2013 fwang <fwang> 1.0.5-2.mga4
+ Revision: 432620
- add upstream patch fixing CVE-2013-1962

* Sat May 25 2013 blino <blino> 1.0.5-1.mga4
+ Revision: 427670
- drop cherry-picks
- 1.0.5

* Sat Mar 30 2013 tv <tv> 1.0.2-7.mga3
+ Revision: 406773
- add patches from FC (fix creating a VM with xen)
- suggests dnsmasq instead of dnsmasq-base
  (fix "Cannot check dnsmasq binary dnsmasq")

* Sun Mar 24 2013 colin <colin> 1.0.2-6.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Sun Mar 10 2013 alien <alien> 1.0.2-5.mga3
+ Revision: 402029
- fix connection loss issue

* Fri Mar 08 2013 alien <alien> 1.0.2-4.mga3
+ Revision: 401739
- XEN: do not force blktap as disk backend

* Wed Feb 06 2013 rtp <rtp> 1.0.2-3.mga3
+ Revision: 394827
- backport upstream fix for the python binding

* Tue Feb 05 2013 rtp <rtp> 1.0.2-2.mga3
+ Revision: 394735
- fix qemu commandline when probing capabilities

* Wed Jan 30 2013 guillomovitch <guillomovitch> 1.0.2-1.mga3
+ Revision: 393598
- new version

  + tmb <tmb>
    - fix inclusion order in P4

* Mon Jan 14 2013 tmb <tmb> 1.0.1-6.mga3
+ Revision: 388067
- work around broken kernel headers (if_bridge.h not selfcontainted) (P4, upstream)

  + colin <colin>
    - Use kernel-source instead. Headers seems not enough.
    - Add kernel-headers to build requires
    - Switch to tmpfiles for [/var]/run dirs

  + umeabot <umeabot>
    - Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 09 2013 cjw <cjw> 1.0.1-3.mga3
+ Revision: 343403
- patch3: fix path substitution in virtlockd.service

* Wed Jan 02 2013 pterjan <pterjan> 1.0.1-2.mga3
+ Revision: 337481
- Fix for _libdir != _libexecdir

* Tue Dec 18 2012 fwang <fwang> 1.0.1-1.mga3
+ Revision: 332243
- update file list
- new version 1.0.1

* Thu Nov 22 2012 blino <blino> 1.0.0-2.mga3
+ Revision: 320995
- require ebtables for libvirtd

* Mon Nov 05 2012 fwang <fwang> 1.0.0-1.mga3
+ Revision: 314304
- new version 1.0.0

* Wed Sep 26 2012 fwang <fwang> 0.10.2-1.mga3
+ Revision: 297893
- new version 0.10.2
- drop unused patch

* Sat Sep 01 2012 fwang <fwang> 0.10.1-1.mga3
+ Revision: 286791
- new version 0.10.1

* Tue Aug 14 2012 guillomovitch <guillomovitch> 0.9.13-3.mga3
+ Revision: 281317
- drop sysinit support

* Fri Aug 03 2012 fwang <fwang> 0.9.13-2.mga3
+ Revision: 278265
- more dir fix
- fix systemd unit dir
- rebuild for new parted

* Sat Jul 14 2012 tv <tv> 0.9.13-1.mga3
+ Revision: 270667
- adjust file list
- rediff patch 1
- new release

* Sat Jun 30 2012 colin <colin> 0.9.12-2.mga3
+ Revision: 265337
- Hopefully fix build against libnl3
- Rebuild against new libudev major

  + ovitters <ovitters>
    - drop patch 1\n-new version 0.9.12

* Mon May 28 2012 blino <blino> 0.9.10-6.mga3
+ Revision: 248291
- call post/preun scripts for libvirtd and libvirt-guests services

* Sat Apr 28 2012 tmb <tmb> 0.9.10-5.mga2
+ Revision: 233764
- Require rpm-helper >= 0.24.8-1 for systemd support

* Wed Apr 18 2012 guillomovitch <guillomovitch> 0.9.10-4.mga2
+ Revision: 231331
- systemd support

* Tue Mar 20 2012 tmb <tmb> 0.9.10-3.mga2
+ Revision: 225055
- build against libnl3 (ubuntu, P1)

* Sun Mar 04 2012 misc <misc> 0.9.10-2.mga2
+ Revision: 217731
- add libyajl-devel as BuildRequires, should fix #4685

* Wed Feb 22 2012 ovitters <ovitters> 0.9.10-1.mga2
+ Revision: 212356
- clean spec
- update file list
- new version

* Tue Jan 10 2012 fwang <fwang> 0.9.9-1.mga2
+ Revision: 194440
- new version 0.9.9

* Tue Dec 20 2011 wally <wally> 0.9.8-1.mga2
+ Revision: 184995
- new version 0.9.8

* Tue Dec 06 2011 tv <tv> 0.9.7-1.mga2
+ Revision: 177975
- fix file list
- fix file list
- new release

* Thu Sep 22 2011 fwang <fwang> 0.9.6-1.mga2
+ Revision: 146723
- new version 0.9.6

* Tue Sep 20 2011 fwang <fwang> 0.9.5-1.mga2
+ Revision: 146121
- update file list
- new version 0.9.5
- add provides for libvirt-client
- new version 0.9.4
- add default-stop section
- rebuild for new gnutls

* Tue Jul 19 2011 fwang <fwang> 0.9.3-2.mga2
+ Revision: 126189
- rebuild for new parted

* Tue Jul 05 2011 fwang <fwang> 0.9.3-1.mga2
+ Revision: 118648
- new version 0.9.3

* Tue Jun 21 2011 saispo <saispo> 0.9.2-1.mga2
+ Revision: 111211
- fix typo
- Comment one file
- Update to 0.9.2

* Mon Apr 18 2011 misc <misc> 0.9.0-1.mga1
+ Revision: 87639
- update to 0.9, synced from Mandriva and guillaume rousse work
- drop patch 0, merged upstream
- add BuildRequires on systemtap and pcap-devel

* Tue Apr 05 2011 misc <misc> 0.8.8-3.mga1
+ Revision: 80706
- rebuild
- add patch from upstream, synced from Mandriva
- build with netcf
- use udev rather than hal, change synced from Matthew Dawkins and Mandriva

* Thu Mar 24 2011 boklm <boklm> 0.8.8-2.mga1
+ Revision: 76183
- rebuild for bug #497

* Mon Mar 07 2011 saispo <saispo> 0.8.8-1.mga1
+ Revision: 65995
- New release 0.8.8

  + misc <misc>
    - add missing Requires ( without iptables, the network do not work )

  + tmb <tmb>
    - imported package libvirt

